"use strict";
// Copyright 2021 The Prometheus Authors
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
var _a;
Object.defineProperty(exports, "__esModule", { value: true });
exports.isFunctionBypassed = exports.getFunction = exports.ValueType = void 0;
var lezer_metricsql_1 = require("@clavinjune/lezer-metricsql");
var ValueType;
(function (ValueType) {
    ValueType["none"] = "none";
    ValueType["vector"] = "vector";
    ValueType["scalar"] = "scalar";
    ValueType["matrix"] = "matrix";
    ValueType["string"] = "string";
})(ValueType = exports.ValueType || (exports.ValueType = {}));
// promqlFunctions is a list of all functions supported by PromQL, including their types.
// Based on https://github.com/prometheus/prometheus/blob/master/promql/parser/functions.go#L26
var promqlFunctions = (_a = {},
    _a[lezer_metricsql_1.Abs] = {
        name: 'abs',
        argTypes: [ValueType.vector],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.Absent] = {
        name: 'absent',
        argTypes: [ValueType.vector],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.AbsentOverTime] = {
        name: 'absent_over_time',
        argTypes: [ValueType.matrix],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.Acos] = {
        name: 'acos',
        argTypes: [ValueType.vector],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.Acosh] = {
        name: 'acosh',
        argTypes: [ValueType.vector],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.Asin] = {
        name: 'asin',
        argTypes: [ValueType.vector],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.Asinh] = {
        name: 'asinh',
        argTypes: [ValueType.vector],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.Atan] = {
        name: 'atan',
        argTypes: [ValueType.vector],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.Atanh] = {
        name: 'atanh',
        argTypes: [ValueType.vector],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.AvgOverTime] = {
        name: 'avg_over_time',
        argTypes: [ValueType.matrix],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.Ceil] = {
        name: 'ceil',
        argTypes: [ValueType.vector],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.Changes] = {
        name: 'changes',
        argTypes: [ValueType.matrix],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.Clamp] = {
        name: 'clamp',
        argTypes: [ValueType.vector, ValueType.scalar, ValueType.scalar],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.ClampMax] = {
        name: 'clamp_max',
        argTypes: [ValueType.vector, ValueType.scalar],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.ClampMin] = {
        name: 'clamp_min',
        argTypes: [ValueType.vector, ValueType.scalar],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.Cos] = {
        name: 'cos',
        argTypes: [ValueType.vector],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.Cosh] = {
        name: 'Cosh',
        argTypes: [ValueType.vector],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.CountOverTime] = {
        name: 'count_over_time',
        argTypes: [ValueType.matrix],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.DaysInMonth] = {
        name: 'days_in_month',
        argTypes: [ValueType.vector],
        variadic: 1,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.DayOfMonth] = {
        name: 'day_of_month',
        argTypes: [ValueType.vector],
        variadic: 1,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.DayOfWeek] = {
        name: 'day_of_week',
        argTypes: [ValueType.vector],
        variadic: 1,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.DayOfYear] = {
        name: 'day_of_year',
        argTypes: [ValueType.vector],
        variadic: 1,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.Deg] = {
        name: 'deg',
        argTypes: [ValueType.vector],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.Delta] = {
        name: 'delta',
        argTypes: [ValueType.matrix],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.Deriv] = {
        name: 'deriv',
        argTypes: [ValueType.matrix],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.Exp] = {
        name: 'exp',
        argTypes: [ValueType.vector],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.Floor] = {
        name: 'floor',
        argTypes: [ValueType.vector],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.HistogramCount] = {
        name: 'histogram_count',
        argTypes: [ValueType.vector],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.HistogramFraction] = {
        name: 'histogram_fraction',
        argTypes: [ValueType.scalar, ValueType.scalar, ValueType.vector],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.HistogramQuantile] = {
        name: 'histogram_quantile',
        argTypes: [ValueType.scalar, ValueType.vector],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.HistogramStdDev] = {
        name: 'histogram_stddev',
        argTypes: [ValueType.vector],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.HistogramStdVar] = {
        name: 'histogram_stdvar',
        argTypes: [ValueType.vector],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.HistogramSum] = {
        name: 'histogram_sum',
        argTypes: [ValueType.vector],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.HoltWinters] = {
        name: 'holt_winters',
        argTypes: [ValueType.matrix, ValueType.scalar, ValueType.scalar],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.Hour] = {
        name: 'hour',
        argTypes: [ValueType.vector],
        variadic: 1,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.Idelta] = {
        name: 'idelta',
        argTypes: [ValueType.matrix],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.Increase] = {
        name: 'increase',
        argTypes: [ValueType.matrix],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.Irate] = {
        name: 'irate',
        argTypes: [ValueType.matrix],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.LabelReplace] = {
        name: 'label_replace',
        argTypes: [ValueType.vector, ValueType.string, ValueType.string, ValueType.string, ValueType.string],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.LabelJoin] = {
        name: 'label_join',
        argTypes: [ValueType.vector, ValueType.string, ValueType.string, ValueType.string],
        variadic: -1,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.LastOverTime] = {
        name: 'last_over_time',
        argTypes: [ValueType.matrix],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.Ln] = {
        name: 'ln',
        argTypes: [ValueType.vector],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.Log10] = {
        name: 'log10',
        argTypes: [ValueType.vector],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.Log2] = {
        name: 'log2',
        argTypes: [ValueType.vector],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.MaxOverTime] = {
        name: 'max_over_time',
        argTypes: [ValueType.matrix],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.MinOverTime] = {
        name: 'min_over_time',
        argTypes: [ValueType.matrix],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.Minute] = {
        name: 'minute',
        argTypes: [ValueType.vector],
        variadic: 1,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.Month] = {
        name: 'month',
        argTypes: [ValueType.vector],
        variadic: 1,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.Pi] = {
        name: 'pi',
        argTypes: [],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.PredictLinear] = {
        name: 'predict_linear',
        argTypes: [ValueType.matrix, ValueType.scalar],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.PresentOverTime] = {
        name: 'present_over_time',
        argTypes: [ValueType.matrix],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.QuantileOverTime] = {
        name: 'quantile_over_time',
        argTypes: [ValueType.scalar, ValueType.matrix],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.Rad] = {
        name: 'rad',
        argTypes: [ValueType.vector],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.Rate] = {
        name: 'rate',
        argTypes: [ValueType.matrix],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.Resets] = {
        name: 'resets',
        argTypes: [ValueType.matrix],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.Round] = {
        name: 'round',
        argTypes: [ValueType.vector, ValueType.scalar],
        variadic: 1,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.Scalar] = {
        name: 'scalar',
        argTypes: [ValueType.vector],
        variadic: 0,
        returnType: ValueType.scalar,
    },
    _a[lezer_metricsql_1.Sgn] = {
        name: 'sgn',
        argTypes: [ValueType.vector],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.Sin] = {
        name: 'sin',
        argTypes: [ValueType.vector],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.Sinh] = {
        name: 'Sinh',
        argTypes: [ValueType.vector],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.Sort] = {
        name: 'sort',
        argTypes: [ValueType.vector],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.SortDesc] = {
        name: 'sort_desc',
        argTypes: [ValueType.vector],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.Sqrt] = {
        name: 'sqrt',
        argTypes: [ValueType.vector],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.StddevOverTime] = {
        name: 'stddev_over_time',
        argTypes: [ValueType.matrix],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.StdvarOverTime] = {
        name: 'stdvar_over_time',
        argTypes: [ValueType.matrix],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.SumOverTime] = {
        name: 'sum_over_time',
        argTypes: [ValueType.matrix],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.Tan] = {
        name: 'tan',
        argTypes: [ValueType.vector],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.Tanh] = {
        name: 'tanh',
        argTypes: [ValueType.vector],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.Time] = {
        name: 'time',
        argTypes: [],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.Timestamp] = {
        name: 'timestamp',
        argTypes: [ValueType.vector],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.Vector] = {
        name: 'vector',
        argTypes: [ValueType.scalar],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.Year] = {
        name: 'year',
        argTypes: [ValueType.vector],
        variadic: 1,
        returnType: ValueType.vector,
    },
    // metricsql
    _a[lezer_metricsql_1.AggrOverTime] = {
        // ToDo, support multiplefunction
        // https://github.com/VictoriaMetrics/VictoriaMetrics/blob/71668637ce7657a09759b1e375d49093bff9672a/app/vmselect/promql/exec_test.go#L7724-L7756
        name: 'aggr_over_time',
        argTypes: [ValueType.string, ValueType.matrix],
        variadic: -1,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.AscentOverTime] = {
        name: 'ascent_over_time',
        argTypes: [ValueType.matrix],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.BitmapAnd] = {
        name: 'bitmap_and',
        argTypes: [ValueType.vector, ValueType.scalar],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.BitmapOr] = {
        name: 'bitmap_or',
        argTypes: [ValueType.vector, ValueType.scalar],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.BitmapXor] = {
        name: 'bitmap_xor',
        argTypes: [ValueType.vector, ValueType.scalar],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.BucketsLimit] = {
        name: 'buckets_limit',
        argTypes: [ValueType.scalar, ValueType.vector],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.ChangesPrometheus] = {
        name: 'changes_prometheus',
        argTypes: [ValueType.matrix],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.CountEqOverTime] = {
        name: 'count_eq_over_time',
        argTypes: [ValueType.matrix, ValueType.scalar],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.CountGtOverTime] = {
        name: 'count_gt_over_time',
        argTypes: [ValueType.matrix, ValueType.scalar],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.CountLeOverTime] = {
        name: 'count_le_over_time',
        argTypes: [ValueType.matrix, ValueType.scalar],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.CountNeOverTime] = {
        name: 'count_ne_over_time',
        argTypes: [ValueType.matrix, ValueType.scalar],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.DecreasesOverTime] = {
        name: 'decreases_over_time',
        argTypes: [ValueType.matrix],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.DefaultRollup] = {
        name: 'default_rollup',
        argTypes: [ValueType.matrix],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.DeltaPrometheus] = {
        name: 'default_rollup',
        argTypes: [ValueType.matrix],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.DerivFast] = {
        name: 'deriv_fast',
        argTypes: [ValueType.matrix],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.DescentOverTime] = {
        name: 'descent_over_time',
        argTypes: [ValueType.matrix],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.DistinctOverTime] = {
        name: 'distinct_over_time',
        argTypes: [ValueType.matrix],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.DropCommonLabels] = {
        name: 'drop_common_labels',
        argTypes: [ValueType.vector, ValueType.string],
        variadic: -1,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.DurationOverTime] = {
        name: 'duration_over_time',
        argTypes: [ValueType.matrix, ValueType.scalar],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.FirstOverTime] = {
        name: 'first_over_time',
        argTypes: [ValueType.matrix],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.GeomeanOverTime] = {
        name: 'geomean_over_time',
        argTypes: [ValueType.matrix],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.HistogramAvg] = {
        name: 'histogram_avg',
        argTypes: [ValueType.vector],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.HistogramOverTime] = {
        name: 'histogram_over_time',
        argTypes: [ValueType.matrix],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.HistogramShare] = {
        name: 'histogram_share',
        argTypes: [ValueType.scalar, ValueType.vector],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.HoeffdingBoundLower] = {
        name: 'hoeffding_bound_lower',
        argTypes: [ValueType.scalar, ValueType.matrix],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.HoeffdingBoundUpper] = {
        name: 'hoeffding_bound_upper',
        argTypes: [ValueType.scalar, ValueType.matrix],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.HoltWinters] = {
        name: 'holt_winters',
        argTypes: [ValueType.matrix, ValueType.scalar, ValueType.scalar],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.Ideriv] = {
        name: 'ideriv',
        argTypes: [ValueType.matrix],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.IncreasePrometheus] = {
        name: 'increase_prometheus',
        argTypes: [ValueType.matrix],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.IncreasePure] = {
        name: 'increase_pure',
        argTypes: [ValueType.matrix],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.IncreasesOverTime] = {
        name: 'increases_over_time',
        argTypes: [ValueType.matrix],
        variadic: 0,
        returnType: ValueType.vector,
    },
    // todo
    _a[lezer_metricsql_1.LabelMove] = {
        name: 'label_move',
        argTypes: [ValueType.vector, ValueType.string],
        variadic: -1,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.LabelSet] = {
        name: 'label_set',
        argTypes: [ValueType.vector, ValueType.string],
        variadic: -1,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.Now] = {
        name: 'now',
        argTypes: [],
        variadic: 0,
        returnType: ValueType.scalar,
    },
    _a[lezer_metricsql_1.Rand] = {
        name: 'rand',
        argTypes: [ValueType.scalar],
        variadic: 1,
        returnType: ValueType.vector,
    },
    // custom transform function
    _a[lezer_metricsql_1.AvgDaily] = {
        name: 'avg_daily',
        argTypes: [ValueType.scalar, ValueType.vector],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.MedianDaily] = {
        name: 'median_daily',
        argTypes: [ValueType.scalar, ValueType.vector],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.AvgWeekly] = {
        name: 'avg_weekly',
        argTypes: [ValueType.scalar, ValueType.vector],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.MedianWeekly] = {
        name: 'median_weekly',
        argTypes: [ValueType.scalar, ValueType.vector],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a[lezer_metricsql_1.MedianWeeklyWithTrends] = {
        name: 'median_weekly_with_trends',
        argTypes: [ValueType.scalar, ValueType.vector],
        variadic: 0,
        returnType: ValueType.vector,
    },
    _a);
function getFunction(id) {
    return promqlFunctions[id];
}
exports.getFunction = getFunction;
function isFunctionBypassed(id) {
    return id === lezer_metricsql_1.HistogramQuantiles ||
        id === lezer_metricsql_1.Integrate ||
        id === lezer_metricsql_1.Interpolate ||
        id === lezer_metricsql_1.KeepLastValue ||
        id === lezer_metricsql_1.KeepNextValue ||
        id === lezer_metricsql_1.LabelCopy ||
        id === lezer_metricsql_1.LabelDel ||
        id === lezer_metricsql_1.LabelGraphiteGroup ||
        id === lezer_metricsql_1.LabelKeep ||
        id === lezer_metricsql_1.LabelLowercase ||
        id === lezer_metricsql_1.LabelMap ||
        id === lezer_metricsql_1.LabelMatch ||
        id === lezer_metricsql_1.LabelMismatch ||
        id === lezer_metricsql_1.LabelTransform ||
        id === lezer_metricsql_1.LabelUppercase ||
        id === lezer_metricsql_1.LabelValue ||
        id === lezer_metricsql_1.Lag ||
        id === lezer_metricsql_1.Lifetime ||
        id === lezer_metricsql_1.LimitOffset ||
        id === lezer_metricsql_1.MadOverTime ||
        id === lezer_metricsql_1.MedianOverTime ||
        id === lezer_metricsql_1.ModeOverTime ||
        id === lezer_metricsql_1.PrometheusBuckets ||
        id === lezer_metricsql_1.QuantilesOverTime ||
        id === lezer_metricsql_1.RandExponential ||
        id === lezer_metricsql_1.RandNormal ||
        id === lezer_metricsql_1.RangeAvg ||
        id === lezer_metricsql_1.RangeFirst ||
        id === lezer_metricsql_1.RangeLast ||
        id === lezer_metricsql_1.RangeLinearRegression ||
        id === lezer_metricsql_1.RangeMad ||
        id === lezer_metricsql_1.RangeMax ||
        id === lezer_metricsql_1.RangeMin ||
        id === lezer_metricsql_1.RangeNormalize ||
        id === lezer_metricsql_1.RangeOverTime ||
        id === lezer_metricsql_1.RangeQuantile ||
        id === lezer_metricsql_1.RangeStddev ||
        id === lezer_metricsql_1.RangeStdvar ||
        id === lezer_metricsql_1.RangeSum ||
        id === lezer_metricsql_1.RangeTrimOutliers ||
        id === lezer_metricsql_1.RangeTrimSpikes ||
        id === lezer_metricsql_1.RangeTrimZscore ||
        id === lezer_metricsql_1.RangeZscore ||
        id === lezer_metricsql_1.RateOverSum ||
        id === lezer_metricsql_1.RemoveResets ||
        id === lezer_metricsql_1.Rollup ||
        id === lezer_metricsql_1.RollupCandlestick ||
        id === lezer_metricsql_1.RollupDelta ||
        id === lezer_metricsql_1.RollupDeriv ||
        id === lezer_metricsql_1.RollupIncrease ||
        id === lezer_metricsql_1.RollupRate ||
        id === lezer_metricsql_1.RollupScrapeInterval ||
        id === lezer_metricsql_1.RunningAvg ||
        id === lezer_metricsql_1.RunningMax ||
        id === lezer_metricsql_1.RunningMin ||
        id === lezer_metricsql_1.RunningSum ||
        id === lezer_metricsql_1.ScrapeInterval ||
        id === lezer_metricsql_1.ShareEqOverTime ||
        id === lezer_metricsql_1.ShareGtOverTime ||
        id === lezer_metricsql_1.ShareLeOverTime ||
        id === lezer_metricsql_1.SmoothExponential ||
        id === lezer_metricsql_1.SortByLabel ||
        id === lezer_metricsql_1.SortByLabelDesc ||
        id === lezer_metricsql_1.SortByLabelNumeric ||
        id === lezer_metricsql_1.SortByLabelNumericDesc ||
        id === lezer_metricsql_1.StaleSamplesOverTime ||
        id === lezer_metricsql_1.Step ||
        id === lezer_metricsql_1.Sum2OverTime ||
        id === lezer_metricsql_1.TfirstOverTime ||
        id === lezer_metricsql_1.TimestampWithName ||
        id === lezer_metricsql_1.TimezoneOffset ||
        id === lezer_metricsql_1.TlastChangeOverTime ||
        id === lezer_metricsql_1.TlastOverTime ||
        id === lezer_metricsql_1.TmaxOverTime ||
        id === lezer_metricsql_1.TminOverTime ||
        id === lezer_metricsql_1.Union ||
        id === lezer_metricsql_1.ZscoreOverTime;
}
exports.isFunctionBypassed = isFunctionBypassed;
//# sourceMappingURL=function.js.map